@@ -3,6 +3,9 @@
 
 #define PY_SSIZE_T_CLEAN
 #include <Python.h>
+
+#include <string>
+
 //#include "greenlet_internal.hpp"
 #include "greenlet_compiler_compat.hpp"
 #include "greenlet_cpython_compat.hpp"
@@ -34,13 +37,13 @@ namespace greenlet
         // implemented as macros.)
         typedef void (*TypeChecker)(void*);
 
-        G_FP_TMPL_STATIC inline void
+        void
         NoOpChecker(void*)
         {
             return;
         }
 
-        G_FP_TMPL_STATIC inline void
+        void
         GreenletChecker(void *p)
         {
             if (!p) {
@@ -63,7 +66,7 @@ namespace greenlet
             }
         }
 
-        G_FP_TMPL_STATIC inline void
+        void
         MainGreenletExactChecker(void *p);
 
         template <typename T, TypeChecker>
@@ -93,7 +96,7 @@ namespace greenlet
 
         typedef _BorrowedGreenlet<PyGreenlet, GreenletChecker> BorrowedGreenlet;
 
-        G_FP_TMPL_STATIC inline void
+        void
         ContextExactChecker(void *p)
         {
             if (!p) {
@@ -133,7 +136,16 @@ namespace greenlet {
     // incref'd, and which the caller MUST NOT decref,
     // should return a ``BorrowedObject``.
 
-    //
+    // XXX: The following two paragraphs do not hold for all platforms.
+    // Notably, 32-bit PPC Linux passes structs by reference, not by
+    // value, so this actually doesn't work. (Although that's the only
+    // platform that doesn't work on.) DO NOT ATTEMPT IT. The
+    // unfortunate consequence of that is that the slots which we
+    // *know* are already type safe will wind up calling the type
+    // checker function (when we had the slots accepting
+    // BorrowedGreenlet, this was bypassed), so this slows us down.
+    // TODO: Optimize this again.
+
     // For a class with a single pointer member, whose constructor
     // does nothing but copy a pointer parameter into the member, and
     // which can then be converted back to the pointer type, compilers
@@ -162,7 +174,7 @@ namespace greenlet {
     protected:
         T* p;
     public:
-        explicit PyObjectPointer(T* it=nullptr) : p(it)
+        PyObjectPointer(T* it=nullptr) : p(it)
         {
             TC(p);
         }
@@ -177,7 +189,7 @@ namespace greenlet {
         // TODO: This should probably not exist here, but be moved
         // down to relevant sub-types.
 
-        inline T* borrow() const noexcept
+        T* borrow() const noexcept
         {
             return this->p;
         }
@@ -187,7 +199,7 @@ namespace greenlet {
             return reinterpret_cast<PyObject*>(this->p);
         }
 
-        inline T* operator->() const noexcept
+         T* operator->() const noexcept
         {
             return this->p;
         }
@@ -197,7 +209,7 @@ namespace greenlet {
             return this->p == Py_None;
         }
 
-        inline PyObject* acquire_or_None() const noexcept
+        PyObject* acquire_or_None() const noexcept
         {
             PyObject* result = this->p ? reinterpret_cast<PyObject*>(this->p) : Py_None;
             Py_INCREF(result);
@@ -206,15 +218,20 @@ namespace greenlet {
 
         explicit operator bool() const noexcept
         {
-            return p != nullptr;
+            return this->p != nullptr;
         }
 
-        inline Py_ssize_t REFCNT() const noexcept
+        bool operator!() const noexcept
+        {
+            return this->p == nullptr;
+        }
+
+        Py_ssize_t REFCNT() const noexcept
         {
             return p ? Py_REFCNT(p) : -42;
         }
 
-        inline PyTypeObject* TYPE() const noexcept
+        PyTypeObject* TYPE() const noexcept
         {
             return p ? Py_TYPE(p) : nullptr;
         }
@@ -261,9 +278,9 @@ namespace greenlet {
 #endif
 
     template<typename T, TypeChecker TC>
-    inline bool operator==(const PyObjectPointer<T, TC>& lhs, const void* const rhs) noexcept
+    inline bool operator==(const PyObjectPointer<T, TC>& lhs, const PyObject* const rhs) noexcept
     {
-        return lhs.borrow_o() == rhs;
+        return static_cast<const void*>(lhs.borrow_o()) == static_cast<const void*>(rhs);
     }
 
     template<typename T, TypeChecker TC, typename X, TypeChecker XC>
@@ -413,6 +430,7 @@ namespace greenlet {
         target = o.relinquish_ownership();
     }
 
+
     class NewReference : public OwnedObject
     {
     private:
@@ -563,8 +581,8 @@ namespace greenlet {
         {
             return reinterpret_cast<PyObject*>(this->p);
         }
-        inline Greenlet* operator->() const noexcept;
-        inline operator Greenlet*() const noexcept;
+        Greenlet* operator->() const noexcept;
+        operator Greenlet*() const noexcept;
     };
 
     typedef _BorrowedGreenlet<PyGreenlet> BorrowedGreenlet;
@@ -780,7 +798,7 @@ namespace greenlet {
         return OwnedObject::consuming(PyObject_Call(this->p, args.borrow(), kwargs.borrow()));
     }
 
-    G_FP_TMPL_STATIC inline void
+    inline void
     ListChecker(void * p)
     {
         if (!p) {
