@@ -14,10 +14,14 @@ import threading
 
 import greenlet
 from . import TestCase
+from . import PY314
+from . import RUNNING_ON_FREETHREAD_BUILD
+from . import WIN
 from .leakcheck import fails_leakcheck
 from .leakcheck import ignores_leakcheck
 from .leakcheck import RUNNING_ON_MANYLINUX
 
+
 # pylint:disable=protected-access
 
 assert greenlet.GREENLET_USE_GC # Option to disable this was removed in 1.0
@@ -38,6 +42,14 @@ class HasFinalizerTracksInstances(object):
         cls.EXTANT_INSTANCES.clear()
 
 
+def fails_leakcheck_except_on_free_thraded(func):
+    if RUNNING_ON_FREETHREAD_BUILD:
+        # These all seem to pass on free threading because
+        # of the changes to the garbage collector
+        return func
+    return fails_leakcheck(func)
+
+
 class TestLeaks(TestCase):
 
     def test_arg_refs(self):
@@ -52,12 +64,15 @@ class TestLeaks(TestCase):
 
     def test_kwarg_refs(self):
         kwargs = {}
+        self.assertEqual(sys.getrefcount(kwargs), 2 if not PY314 else 1)
         # pylint:disable=unnecessary-lambda
         g = greenlet.greenlet(
-            lambda **kwargs: greenlet.getcurrent().parent.switch(**kwargs))
+            lambda **gkwargs: greenlet.getcurrent().parent.switch(**gkwargs))
         for _ in range(100):
             g.switch(**kwargs)
-        self.assertEqual(sys.getrefcount(kwargs), 2)
+        # Python 3.14 elides reference counting operations
+        # in some cases. See https://github.com/python/cpython/pull/130708
+        self.assertEqual(sys.getrefcount(kwargs), 2 if not PY314 else 1)
 
 
     @staticmethod
@@ -261,7 +276,7 @@ class TestLeaks(TestCase):
         finally:
             greenlet._greenlet.enable_optional_cleanup(True)
 
-    @fails_leakcheck
+    @fails_leakcheck_except_on_free_thraded
     def test_issue251_issue252_need_to_collect_in_background(self):
         # Between greenlet 1.1.2 and the next version, this was still
         # failing because the leak of the list still exists when we
@@ -282,7 +297,7 @@ class TestLeaks(TestCase):
         # for some reason, but I've never seen it pass on macOS.
         self._check_issue251(manually_collect_background=False)
 
-    @fails_leakcheck
+    @fails_leakcheck_except_on_free_thraded
     def test_issue251_issue252_need_to_collect_in_background_cleanup_disabled(self):
         self.expect_greenlet_leak = True
         greenlet._greenlet.enable_optional_cleanup(False)
@@ -291,7 +306,7 @@ class TestLeaks(TestCase):
         finally:
             greenlet._greenlet.enable_optional_cleanup(True)
 
-    @fails_leakcheck
+    @fails_leakcheck_except_on_free_thraded
     def test_issue251_issue252_explicit_reference_not_collectable(self):
         self._check_issue251(
             manually_collect_background=False,
@@ -351,6 +366,11 @@ class TestLeaks(TestCase):
         # Like the above test, but what if there are a bunch of
         # unfinished greenlets in a thread that dies?
         # Does it matter if we deallocate in the thread or not?
+
+        # First, make sure we can get useful measurements. This will
+        # be skipped if not.
+        self.get_process_uss()
+
         EXIT_COUNT = [0]
 
         def f():
@@ -437,6 +457,17 @@ class TestLeaks(TestCase):
     # Because the main greenlets from the background threads do not exit in a timely fashion,
     # we fail the object-based leakchecks.
     def test_untracked_memory_doesnt_increase_unfinished_thread_dealloc_in_main(self):
+        # Between Feb 10 and Feb 20 2026, this test started failing on
+        # Github Actions, windows 3.14t. With no relevant code changes on
+        # our part. Both versions were 3.14.3 (same build). The only change
+        # is the Github actions "Runner Image". The working one was version
+        # 20260202.17.1, while the updated failing version was
+        # 20260217.31.1. Both report the same version of the operating system
+        # (Microsoft Windows Server 2025 10.0.26100).
+        #
+        # Reevaluate on future runner image releases.
+        if WIN and RUNNING_ON_FREETHREAD_BUILD and PY314:
+            self.skipTest("Windows 3.14t appears to leak. No other platform does.")
         self._check_untracked_memory_thread(deallocate_in_thread=False)
 
 if __name__ == '__main__':
